==> vue-simple-forms-0.2.0.tgz: package/lib/formCreateMixin.js <==
"use strict";Object.defineProperty(exports,"__esModule",{value:!0}),exports.FormCreateMixin=exports.createForm=void 0;function ownKeys(a,b){var c=Object.keys(a);if(Object.getOwnPropertySymbols){var d=Object.getOwnPropertySymbols(a);b&&(d=d.filter(function(b){return Object.getOwnPropertyDescriptor(a,b).enumerable})),c.push.apply(c,d)}return c}function _objectSpread(a){for(var b,c=1;c<arguments.length;c++)b=null==arguments[c]?{}:arguments[c],c%2?ownKeys(Object(b),!0).forEach(function(c){_defineProperty(a,c,b[c])}):Object.getOwnPropertyDescriptors?Object.defineProperties(a,Object.getOwnPropertyDescriptors(b)):ownKeys(Object(b)).forEach(function(c){Object.defineProperty(a,c,Object.getOwnPropertyDescriptor(b,c))});return a}function _defineProperty(a,b,c){return b in a?Object.defineProperty(a,b,{value:c,enumerable:!0,configurable:!0,writable:!0}):a[b]=c,a}/**
 * Create a Vue form
 *
 * @param  {string} name    - Form name ('data' key)
 * @param  {Object} fields  - Form fields and initial values
 * @param  {Object} options - Form configuration options
 */var createForm=function(a,b){/**
   * Determine whether any form fields have changed
   * @return {boolean} - Whether any fields have changed
   */function c(){var a=this;return Object.keys(this.fields).some(function(b){var c=a.fields[b],d=a._initial[b];return c!==d})}// Only calculate "changed" property if necessary (default)
var d=2<arguments.length&&arguments[2]!==void 0?arguments[2]:{},e=d.calculateChanged,f=d.flags,g=void 0===f?{}:f,h=_defineProperty({},a,{// Clone the fields to set as initial values (for reset)
_initial:_objectSpread({},b),flags:_objectSpread(_objectSpread({},g),{},{// NOTE: Declared even though overridden so that it is tracked by object
changed:!1,get disabled(){return this.loading||this.submitting},loading:!1,submitting:!1}),fields:b,/**
       * Get the form values
       * @return {Object} - Form values
       */getValues:function getValues(){return this.fields},/**
       * Set a form flag
       * @param {string}  flag  - Form flag name
       * @param {boolean} value - Form flag value
       */setFlag:function setFlag(a,b){this.flags[a]=b},/**
       * Set whether the form is loading
       * @param {boolean} isLoading - Whether form is loading
       */setLoading:function setLoading(a){this.setFlag("loading",a)},/**
       * Set whether the form is submitting
       * @param {boolean} isSubmitting - Whether form is submitting
       */setSubmitting:function setSubmitting(a){this.setFlag("submitting",a)},/**
       * Set the form values
       * @param {Object}  values     - New form values
       * @param {boolean} setInitial - Whether initial values should be updated
       */setValues:function setValues(a){var b=this,c=!(1<arguments.length&&arguments[1]!==void 0)||arguments[1];Object.keys(a).forEach(function(c){var d=a[c];b.fields[c]=d}),c&&Object.keys(a).forEach(function(c){var d=a[c];b._initial[c]=d})},/**
       * Reset the form to its initial values
       */reset:function reset(){var a=this;Object.keys(this._initial).forEach(function(b){var c=a._initial[b];a.fields[b]=c})}});if(!(void 0!==e)||e){// Need to bind "this" context since "Object.defineProperty" uses the base object!
var i=c.bind(h[a]);Object.defineProperty(h[a].flags,"changed",{get:i})}else delete h[a].flags.changed;return h};/**
 * Vue form state management mixin
 *
 * @param {string}  name                     - Form name ('data' key)
 * @param {Object}  fields                   - Form fields and initial values
 * @param {Object}  options                  - Form configuration options
 * @param {boolean} options.calculateChanged - Whether form "changed" flag is calculated
 * @param {Object}  options.flags            - Additional custom flags
 */exports.createForm=createForm;var FormCreateMixin=function(a,b,c){return{data:function data(){return _objectSpread({},createForm.call(this,a,b,c))}}};/* eslint no-underscore-dangle: off */exports.FormCreateMixin=FormCreateMixin;

==> vue-simple-forms-0.2.2.tgz: package/lib/formCreateMixin.js <==
"use strict";Object.defineProperty(exports,"__esModule",{value:!0}),exports.FormCreateMixin=exports.createForm=void 0;function ownKeys(a,b){var c=Object.keys(a);if(Object.getOwnPropertySymbols){var d=Object.getOwnPropertySymbols(a);b&&(d=d.filter(function(b){return Object.getOwnPropertyDescriptor(a,b).enumerable})),c.push.apply(c,d)}return c}function _objectSpread(a){for(var b,c=1;c<arguments.length;c++)b=null==arguments[c]?{}:arguments[c],c%2?ownKeys(Object(b),!0).forEach(function(c){_defineProperty(a,c,b[c])}):Object.getOwnPropertyDescriptors?Object.defineProperties(a,Object.getOwnPropertyDescriptors(b)):ownKeys(Object(b)).forEach(function(c){Object.defineProperty(a,c,Object.getOwnPropertyDescriptor(b,c))});return a}function _defineProperty(a,b,c){return b in a?Object.defineProperty(a,b,{value:c,enumerable:!0,configurable:!0,writable:!0}):a[b]=c,a}/**
 * Create a Vue form
 *
 * @param  {string} name    - Form name ('data' key)
 * @param  {Object} fields  - Form fields and initial values
 * @param  {Object} options - Form configuration options
 */var createForm=function(a,b){/**
   * Determine whether any form fields have changed
   * @return {boolean} - Whether any fields have changed
   */function c(){var a=this;return Object.keys(this.fields).some(function(b){var c=a.fields[b],d=a._initial[b];return c!==d})}// Only calculate "changed" property if necessary (default)
var d=2<arguments.length&&arguments[2]!==void 0?arguments[2]:{},e=d.calculateChanged,f=d.flags,g=void 0===f?{}:f,h=_defineProperty({},a,{// Clone the fields to set as initial values (for reset)
_initial:_objectSpread({},b),flags:_objectSpread(_objectSpread({},g),{},{// NOTE: Declared even though overridden so that it is tracked by object
changed:!1,get disabled(){return this.loading||this.submitting},loading:!1,submitting:!1}),fields:b,/**
       * Get the form values
       * @return {Object} - Form values
       */getValues:function getValues(){return this.fields},/**
       * Set a form flag
       * @param {string}  flag  - Form flag name
       * @param {boolean} value - Form flag value
       */setFlag:function setFlag(a,b){// Only set flags that exist or are custom!
void 0===this.flags[a]||(this.flags[a]=!!b)},/**
       * Set whether the form is loading
       * @param {boolean} isLoading - Whether form is loading
       */setLoading:function setLoading(a){this.setFlag("loading",a)},/**
       * Set whether the form is submitting
       * @param {boolean} isSubmitting - Whether form is submitting
       */setSubmitting:function setSubmitting(a){this.setFlag("submitting",a)},/**
       * Set the form values
       * @param {Object}  values     - New form values
       * @param {boolean} setInitial - Whether initial values should be updated
       */setValues:function setValues(a){var b=this,c=!(1<arguments.length&&arguments[1]!==void 0)||arguments[1];Object.keys(a).forEach(function(c){var d=a[c];b.fields[c]=d}),c&&Object.keys(a).forEach(function(c){var d=a[c];b._initial[c]=d})},/**
       * Reset the form to its initial values
       */reset:function reset(){var a=this;Object.keys(this._initial).forEach(function(b){var c=a._initial[b];a.fields[b]=c})}});if(!(void 0!==e)||e){// Need to bind "this" context since "Object.defineProperty" uses the base object!
var i=c.bind(h[a]);Object.defineProperty(h[a].flags,"changed",{get:i})}else delete h[a].flags.changed;return h};/**
 * Vue form state management mixin
 *
 * @param {string}  name                     - Form name ('data' key)
 * @param {Object}  fields                   - Form fields and initial values
 * @param {Object}  options                  - Form configuration options
 * @param {boolean} options.calculateChanged - Whether form "changed" flag is calculated
 * @param {Object}  options.flags            - Additional custom flags
 */exports.createForm=createForm;var FormCreateMixin=function(a,b,c){return{data:function data(){return _objectSpread({},createForm.call(this,a,b,c))}}};/* eslint no-underscore-dangle: off */exports.FormCreateMixin=FormCreateMixin;
